@@ -265,6 +265,14 @@ class Cursor(DBAPICursor):
     def close(self):
         """Close the operation handle"""
         self.connection.close(self._query_id)
+        self._arraysize = None
+        self.connection = None
+        self._data = None
+        self._query_columns_description = None
+        self._description = None
+        self._query_id = None
+        self._batch = None
+        self._rowcount = None
         pass
 
     def getTables(self):
@@ -353,7 +361,8 @@ class Cursor(DBAPICursor):
         # _logger.info("fetching all from overriden method")
         if size is None:
             size = self.arraysize
-        self._data = list()
+        if self._data is None:
+            self._data = list()
         while len(self._data) < size:
             # _logger.info("fetching next batch from fetch many")
             rows = self.fetch_batch()
@@ -365,8 +374,8 @@ class Cursor(DBAPICursor):
             rows = self._data
             self._data = None
             return rows
-        rows = self._data[0:size]
-        self._data = None
+        rows = self._data[:size]
+        self._data = self._data[size:]
         return rows
 
     def fetchone(self):
@@ -408,11 +417,11 @@ class Error(Exception):
 
 
 if __name__ == '__main__':
-    connection = connect(host="44.201.53.50",
+    connection = connect(host="44.200.35.172",
                          port=9000,
                          scheme="e6xdb",
                          username="admin",
-                         database="perf_hive_100gb",
+                         database="tydy",
                          auth=None,
                          configuration=None,
                          kerberos_service_name=None,
@@ -421,7 +430,7 @@ if __name__ == '__main__':
                          ssl_cert=None,
                          thrift_transport=None)
     cursor = Cursor(connection)
-    cursor.execute("select * from call_center limit 3;")
+    cursor.execute("SELECT offer_created_date from candidate_offer_letter limit 100;")
     bdata = []
     for i in range(10):
         bdata += cursor.fetchmany()
